pub struct ReadHandle<T>(_);
A handle to the read half of the cell. Getting a value from the read handle will never block.

Implementations

Gets the value from the cell. Returns None if the WriteHandle as been dropped.

Safety

The user of this function must be sure that the WriteHandle has not been dropped.