pub struct WriteHandle<T: Clone>(_);
A handle to the write half of the cell. When this handle is dropped the backing data is also dropped.

Implementations

Set the value of the cell.

Make the changes the to cell since the last set visible to the readers.