Struct left_right_cell::WriteHandle
source · [−]pub struct WriteHandle<T: Clone>(_);Expand description
A handle to the write half of the cell. When this handle is dropped the backing data is also dropped.
Implementations